@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::GitHub::Create;
 {
-  $Dist::Zilla::Plugin::GitHub::Create::VERSION = '0.34';
+  $Dist::Zilla::Plugin::GitHub::Create::VERSION = '0.35';
 }
 
 use strict;
@@ -29,13 +29,31 @@ has 'prompt' => (
 	default	=> 0
 );
 
+has 'has_issues' => (
+	is	=> 'ro',
+	isa	=> 'Bool',
+	default	=> 1
+);
+
+has 'has_wiki' => (
+	is	=> 'ro',
+	isa	=> 'Bool',
+	default	=> 1
+);
+
+has 'has_downloads' => (
+	is	=> 'ro',
+	isa	=> 'Bool',
+	default	=> 1
+);
+
 =head1 NAME
 
 Dist::Zilla::Plugin::GitHub::Create - Create a new GitHub repo on dzil new
 
 =head1 VERSION
 
-version 0.34
+version 0.35
 
 =head1 SYNOPSIS
 
@@ -109,6 +127,18 @@ sub after_mint {
 	$params -> {'public'} = $self -> public;
 	$params -> {'description'} = $opts -> {'descr'} if $opts -> {'descr'};
 
+	$params -> {'has_issues'} = $self -> has_issues;
+	$self -> log([ 'Issues are %s', $params -> {'has_issues'}   ?
+				'enabled' : 'disabled' ]);
+
+	$params -> {'has_wiki'} = $self -> has_wiki;
+	$self -> log([ 'Wiki is %s', $params -> {'has_wiki'}   ?
+				'enabled' : 'disabled' ]);
+
+	$params -> {'has_downloads'} = $self -> has_downloads;
+	$self -> log([ 'Downloads are %s', $params -> {'has_downloads'}   ?
+				'enabled' : 'disabled' ]);
+
 	my $url = $self -> api.'/user/repos';
 
 	if ($pass) {
@@ -192,6 +222,18 @@ Specifies the git remote name to be added (default 'origin'). This will point to
 the newly created GitHub repository's private URL. See L</"ADDING REMOTE"> for
 more info.
 
+=item C<has_issues>
+
+Enable issues for the new repository if this option is set to true (default).
+
+=item C<has_wiki>
+
+Enable the wiki for the new repository if this option is set to true (default).
+
+=item C<has_downloads>
+
+Enable downloads for the new repository if this option is set to true (default).
+
 =back
 
 =head1 ADDING REMOTE
